@@ -9,3 +9,8 @@
 #    packageStartupMessage(" your current TZ:",paste(Sys.getenv("TZ")))
 #  }
 }
+
+if(getRversion() < "2.11.0") {
+    .POSIXct <- function(xx, tz = NULL)
+    structure(xx, class = c("POSIXt", "POSIXct"), tzone = tz)
+}
