@@ -26,7 +26,7 @@
 static const
 R_CallMethodDef callMethods[] = {
   {"add_class",             (DL_FUNC) &add_class,               2},
-  {"coredata",              (DL_FUNC) &coredata,                1},
+  {"coredata",              (DL_FUNC) &coredata,                2},
   {"coredata_xts",          (DL_FUNC) &coredata_xts,            1},
   {"do_xtsAttributes",      (DL_FUNC) &do_xtsAttributes,        1},
   {"do_xtsCoreAttributes",  (DL_FUNC) &do_xtsCoreAttributes,    1},
@@ -36,6 +36,7 @@ R_CallMethodDef callMethods[] = {
   {"tryXts",                (DL_FUNC) &tryXts,                  1},
   {"do_rbind_xts",          (DL_FUNC) &do_rbind_xts,            3},
   {"do_subset_xts",         (DL_FUNC) &do_subset_xts,           4},
+  {"naCheck",               (DL_FUNC) &naCheck,                 2},
   {NULL,                    NULL,                               0}
 };
 
@@ -64,4 +65,5 @@ void R_init_xts(DllInfo *info)
   R_RegisterCCallable("xts","isXts",        (DL_FUNC) &isXts);
   R_RegisterCCallable("xts","tryXts",       (DL_FUNC) &tryXts);
   RegisterXTS(rbindXts);
+  RegisterXTS(naCheck);
 }
